#include "Ball.hpp"
#include <ctime>

#include <Graphics/Graphics.hpp>


Ball::Ball() : radius( 0.1f ), speed_percent( make_vector( (float)rand() / RAND_MAX * 2 - 1, (float)rand() / RAND_MAX * 2 - 1 ) )
{
	color = rand() % NUM_COLORS;
	float x = (rand() / (double)RAND_MAX) * 2 - 1;
	float y = (rand() / (double)RAND_MAX) * 2 - 1;
	
	pos = make_vector( x, y );
}

Ball::~Ball()
{}

void Ball::update(float elapsed_time, float speed ) 
{
	
	pos.x += elapsed_time * speed * speed_percent.x;
	pos.y += elapsed_time * speed * speed_percent.y;
	
	if( 1 - fabs( pos.x ) < radius && ( ( speed_percent.x > 0 && pos.x > 0 ) || ( speed_percent.x < 0 && pos.x < 0 ) ) )
		speed_percent.x *= -1;
		
	if( 1 - fabs( pos.y ) < radius && ( ( speed_percent.y > 0 && pos.y > 0 ) || ( speed_percent.y < 0 && pos.y < 0 ) ) )
		speed_percent.y *= -1;

}

void Ball::draw()
{
	draw_circle( pos.x, pos.y, radius );
}

void Ball::draw_square( float x, float y, float size )
{
	glBegin( GL_LINES );
	set_color();
	glVertex2f( x - size / 2.0, y + size / 2.0 );
	glVertex2f( x + size / 2.0, y + size / 2.0 );
	
	glVertex2f( x + size / 2.0, y + size / 2.0 );
	glVertex2f( x + size / 2.0, y - size / 2.0 );
	
	glVertex2f( x + size / 2.0, y - size / 2.0 );
	glVertex2f( x - size / 2.0, y - size / 2.0 );
	
	glVertex2f( x - size / 2.0, y - size / 2.0 );
	glVertex2f( x - size / 2.0, y + size / 2.0 );
	glEnd();
}

void Ball::draw_circle( float x, float y, float radius )
{
	// taken from http://steinsoft.net/index.php?site=Programming/Code%20Snippets/OpenGL/no5
	float DEG2RAD = 3.14159/180;
	 
	glBegin(GL_LINE_LOOP);
	set_color();

	for (int i=0; i < 360; i++)
	{
		float degInRad = i*DEG2RAD;
		glVertex2f(cos(degInRad)*radius + x, sin(degInRad)*radius + y );
	}
	 
	glEnd();
}

void Ball::set_color()
{
	// printf( "Setting color to %d\n", color );

	switch( color )
	{
		case BLUE: 
			glColor3f( 0.0, 0.0, 1.0 );
			break;
		case RED:
			glColor3f( 1.0, 0.0, 0.0 );
			break;
		case GREEN:
			glColor3f( 0.0, 1.0, 0.0 );
			break;
		case WHITE:
			glColor3f( 1.0, 1.0, 1.0 );
			break;
		case YELLOW:
			glColor3f( 1.0, 1.0, 0.2 );
			break;
		case PURPLE:
			glColor3f( 1.0, 0.0, 1.0 ); 
			break;
		default:
			printf( "ERROR! Tried to set color of %d when NUM_COLORS = %d\n", color, NUM_COLORS );
	}
}

bool Ball::test_collide( Ball other )
{
	float x_dist = other.pos.x - pos.x;
	float y_dist = other.pos.y - pos.y;
	float dist = sqrt( x_dist * x_dist + y_dist * y_dist );

	return dist < (radius + other.radius);
}

