#include "Play.hpp"
#include "Ball.hpp"

#include <Graphics/Graphics.hpp>

Play::Play() : mouse_pos(make_vector(0.0f, 0.0f)), speed( .5 ), score( 0 )
{
	cursor = Ball();
	// gives the cursor an original random color
	cursor.color = rand() % NUM_COLORS;
	cursor.radius = .05;
	
	for( int i = 0; i < NUM_COLORS; i++ )
	{
		balls[i] = Ball();
		balls[i].color = i;
	}
}

Play::~Play() {
}

void Play::draw() {
	glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
	glClear(GL_COLOR_BUFFER_BIT);
	
	for( int i = 0; i < NUM_COLORS; i++ )
	{
		balls[i].draw();
	}
	
	cursor.draw();
}

void Play::update(float elapsed_time) {
	for( int i = 0; i < NUM_COLORS; i++ )
	{
		balls[i].update( elapsed_time, speed );
	}
}

void Play::handle_event(SDL_Event const &event) {
	//Handle events here:
	if (event.type == SDL_KEYDOWN) {
		if (event.key.keysym.sym == SDLK_ESCAPE) {
			//escape quits.
			quit_screen(this);
		}
	}
	
	// if the mouse is pressed, check where it's happening and what should happen due to that
	if( event.type == SDL_MOUSEBUTTONDOWN ) 
	{
		if( event.button.button == SDL_BUTTON_LEFT )
			process_left_click();
	}
	
	// gets the mouse position
	if (event.type == SDL_MOUSEMOTION) {
		mouse_pos.x = event.motion.x / float(Graphics::screen.x) * Graphics::aspectf() * 2.0f - Graphics::aspectf();
		mouse_pos.y = event.motion.y / float(Graphics::screen.y) *-2.0f + 1.0f;
		
		cursor.pos.x = mouse_pos.x;
		cursor.pos.y = mouse_pos.y;
	}
}

void Play::process_left_click()
{
	int i = 0;
	for( i = 0; i < NUM_COLORS; i++ )
	{
		if( balls[i].test_collide( cursor ) )
		{
			if( balls[i].color == cursor.color )
			{
				speed += .05;
				
				bool num_taken[NUM_COLORS];
				for( int j = 0; j < NUM_COLORS; j++ )
				{
					num_taken[j] = false;
				}
				// if they did not click on the right color, switch all the colors
				for( int j = NUM_COLORS - 1; j >= 0; j-- )
				{
					// gets a random number from 0 to j-1
					int rand_color = rand() % (j + 1);
					while( num_taken[rand_color] )
					{
						rand_color++;
					}
					num_taken[rand_color] = true;
					balls[j].color = rand_color;
				}
				
				score++;
				
				if( score % 5 == 0 )
				{
					cursor.color++;
					if( cursor.color >= NUM_COLORS )
						cursor.color = 0;
				}
			}
			else
			{
				cursor.color = rand() % NUM_COLORS;
				score = 0;
			}
			
			break;
		}
	}
	
	if( i == NUM_COLORS )
	{
		speed -= .05;
		if( speed < 0 )
			speed = 0;
	}
	
	
}



